@@ -19,7 +19,6 @@
 
 
 #include "oxygensizegrip.h"
-#include "oxygensizegrip.moc"
 
 #include <KDecoration2/DecoratedClient>
 
@@ -76,10 +75,6 @@ namespace Oxygen
 
     }
 
-    //_____________________________________________
-    SizeGrip::~SizeGrip( void )
-    {}
-
     //_____________________________________________
     void SizeGrip::updateActiveState( void )
     {
