@@ -31,7 +31,6 @@ DEALINGS IN THE SOFTWARE.
 
 namespace Oxygen
 {
-    class AnimationConfigWidget;
 
     class StyleConfig: public QWidget, Ui::OxygenStyleConfig
     {
@@ -43,10 +42,6 @@ namespace Oxygen
         //* constructor
         explicit StyleConfig(QWidget*);
 
-        //* destructor
-        virtual ~StyleConfig( void )
-        {}
-
         Q_SIGNALS:
 
         //* emmited whenever one option is changed.
@@ -68,19 +63,13 @@ namespace Oxygen
         //* reset to saved configuration
         void reset( void );
 
-        protected Q_SLOTS:
-
-        //* update layout
-        /** needed in expert mode to accommodate with animations config widget size changes */
-        void updateLayout( void );
-
         //* update modified state when option is checked/unchecked
         void updateChanged( void );
 
         protected:
 
-        //! event processing
-        bool event( QEvent* ) ;
+        //* event processing
+        bool event( QEvent* ) override;
 
         // menu mode from ui
         int menuMode( void ) const;
@@ -88,6 +77,12 @@ namespace Oxygen
         // expander size from ui
         int triangularExpanderSize( void ) const;
 
+        private Q_SLOTS:
+
+        //* update layout
+        /** needed in expert mode to accommodate with animations config widget size changes */
+        void updateLayout( void );
+
     };
 
 }
