@@ -50,16 +50,11 @@ namespace Oxygen
 {
     //_______________________________________________________________
     DemoDialog::DemoDialog( QWidget* parent ):
-        QDialog( parent ),
-        _enableCheckBox( 0 ),
-        _rightToLeftCheckBox( 0 )
+        KPageDialog( parent )
     {
 
         setWindowTitle( i18n( "Oxygen Demo" ) );
 
-        // ui
-        setupUi(this);
-
         #if OXYGEN_USE_KDE4
         // install Quit shortcut
         connect( new QShortcut( KStandardShortcut::quit().primary(), this ), SIGNAL(activated()), SLOT(close()) );
@@ -70,7 +65,17 @@ namespace Oxygen
         { connect( new QShortcut( sequence, this ), SIGNAL(activated()), SLOT(close()) ); }
         #endif
 
+        #if OXYGEN_USE_KDE4
+        setButtons( KDialog::Ok );
+        auto buttonBox = findChild<QDialogButtonBox*>();
+        #else
+        // button box
+        auto buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok, Qt::Horizontal );
+        setButtonBox( buttonBox );
+
+        // connection
         connect( buttonBox->button( QDialogButtonBox::Ok ), SIGNAL(clicked()), SLOT(close()) );
+        #endif
 
         // customize button box
         _enableCheckBox = new QCheckBox( i18n( "Enabled" ) );
@@ -82,114 +87,120 @@ namespace Oxygen
         connect( _rightToLeftCheckBox, SIGNAL(toggled(bool)), SLOT(toggleRightToLeft(bool)) );
         buttonBox->addButton( _rightToLeftCheckBox, QDialogButtonBox::ResetRole );
 
-#ifdef HAVE_SCHEME_CHOOSER
-        WidgetStyleChooser *styleChooser = new WidgetStyleChooser(this);
+        #ifdef HAVE_SCHEME_CHOOSER
+        auto styleChooser = new WidgetStyleChooser(this);
         styleChooser->createStyleSelectionMenu( i18n( "Style" ) );
         buttonBox->addButton( styleChooser, QDialogButtonBox::ResetRole );
 
-        ColorSchemeChooser *colChooser = new ColorSchemeChooser( this );
+        auto colChooser = new ColorSchemeChooser( this );
         buttonBox->addButton( colChooser, QDialogButtonBox::ResetRole );
-#endif
+        #endif
 
         // connections
-        connect( pageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateWindowTitle(KPageWidgetItem*)) );
-        connect( pageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateEnableState(KPageWidgetItem*)) );
-        KPageWidgetItem *page;
-        DemoWidget *widget;
+        connect( this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateWindowTitle(KPageWidgetItem*)) );
+        connect( this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateEnableState(KPageWidgetItem*)) );
+
+        auto setPageIcon = []( KPageWidgetItem* page, const QString& iconName )
+        {
+            #if OXYGEN_USE_KDE4
+            page->setIcon( KIcon( iconName ) );
+            #else
+            page->setIcon( QIcon::fromTheme( iconName ) );
+            #endif
+        };
+
+        KPageWidgetItem* page = nullptr;
+        QVector<KPageWidgetItem*> items;
 
         // inputs
         {
-            page = new KPageWidgetItem( widget = new InputDemoWidget() );
+            page = new KPageWidgetItem( new InputDemoWidget() );
             page->setName( i18n("Input Widgets") );
             setPageIcon( page, QStringLiteral( "edit-rename" ) );
             page->setHeader( i18n("Shows the appearance of text input widgets") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // tab
         {
-            page = new KPageWidgetItem( widget = new TabDemoWidget() );
+            page = new KPageWidgetItem( new TabDemoWidget() );
             page->setName( i18n("Tab Widgets") );
             setPageIcon( page, QStringLiteral( "tab-detach" ) );
             page->setHeader( i18n("Shows the appearance of tab widgets") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // buttons
         {
-            page = new KPageWidgetItem( widget = new ButtonDemoWidget() );
+            page = new KPageWidgetItem( new ButtonDemoWidget() );
             page->setName( i18n("Buttons") );
             setPageIcon( page, QStringLiteral( "go-jump-locationbar" ) );
             page->setHeader( i18n("Shows the appearance of buttons") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // lists
         {
-            page = new KPageWidgetItem( widget = new ListDemoWidget() );
+            page = new KPageWidgetItem( new ListDemoWidget() );
             page->setName( i18n("Lists") );
             setPageIcon( page, QStringLiteral( "view-list-tree" ) );
             page->setHeader( i18n("Shows the appearance of lists, trees and tables") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
-
+            addPage( page );
+            items.append( page );
         }
 
         // frames
         {
-            page = new KPageWidgetItem( widget = new FrameDemoWidget() );
+            page = new KPageWidgetItem( new FrameDemoWidget() );
             page->setName( i18n("Frames") );
             setPageIcon( page, QStringLiteral( "draw-rectangle" ) );
             page->setHeader( i18n("Shows the appearance of various framed widgets") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // mdi
         {
-            page = new KPageWidgetItem( widget = new MdiDemoWidget() );
+            page = new KPageWidgetItem( new MdiDemoWidget() );
             page->setName( i18n( "MDI Windows" ) );
             setPageIcon( page, QStringLiteral( "preferences-system-windows" ) );
             page->setHeader( i18n( "Shows the appearance of MDI windows" ) );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // sliders
         {
-            page = new KPageWidgetItem( widget = new SliderDemoWidget() );
+            page = new KPageWidgetItem( new SliderDemoWidget() );
             page->setName( i18n("Sliders") );
             setPageIcon( page, QStringLiteral( "measure" ) );
             page->setHeader( i18n("Shows the appearance of sliders, progress bars and scrollbars") );
-            pageWidget->addPage( page );
-            _widgets.append( widget );
+            addPage( page );
+            items.append( page );
         }
 
         // benchmark
         {
-            BenchmarkWidget* benchmarkWidget( new BenchmarkWidget() );
+            auto benchmarkWidget( new BenchmarkWidget() );
             page = new KPageWidgetItem( benchmarkWidget );
             page->setName( i18n("Benchmark") );
             setPageIcon( page, QStringLiteral( "system-run" ) );
             page->setHeader( i18n("Emulates user interaction with widgets for benchmarking") );
-            benchmarkWidget->init( pageWidget );
-
-            pageWidget->addPage( page );
-            _widgets.append( benchmarkWidget );
+            benchmarkWidget->init( this, items );
+            addPage( page );
+            items.append( page );
         }
 
         // connections
         QShortcut* shortcut( new QShortcut( Qt::CTRL + Qt::Key_X, this ) );
-        foreach( DemoWidget* widget, _widgets )
+        for( auto item:items )
         {
-            if( widget->metaObject()->indexOfSlot( "benchmark()" ) >= 0 )
-            { connect( shortcut, SIGNAL(activated()), widget, SLOT(benchmark()) ); }
-
-            connect( this, SIGNAL(abortSimulations()), &widget->simulator(), SLOT(abort()) );
-
+            if( item->widget()->metaObject()->indexOfSlot( "benchmark()" ) >= 0 )
+            { connect( shortcut, SIGNAL(activated()), item->widget(), SLOT(benchmark()) ); }
+            connect( this, SIGNAL(abortSimulations()), &static_cast<DemoWidget*>(item->widget())->simulator(), SLOT(abort()) );
         }
 
     }
@@ -222,8 +233,8 @@ namespace Oxygen
     //_______________________________________________________________
     void DemoDialog::toggleEnable( bool value )
     {
-        if( !( pageWidget->currentPage() && pageWidget->currentPage()->widget() ) ) return;
-        pageWidget->currentPage()->widget()->setEnabled( value );
+        if( !( currentPage() && currentPage()->widget() ) ) return;
+        currentPage()->widget()->setEnabled( value );
     }
 
     //_______________________________________________________________
@@ -234,24 +245,14 @@ namespace Oxygen
     void DemoDialog::closeEvent( QCloseEvent* event )
     {
         emit abortSimulations();
-        QDialog::closeEvent( event );
+        KPageDialog::closeEvent( event );
     }
 
     //_______________________________________________________________
     void DemoDialog::hideEvent( QHideEvent* event )
     {
         emit abortSimulations();
-        QDialog::hideEvent( event );
-    }
-
-    //_______________________________________________________________
-    void DemoDialog::setPageIcon( KPageWidgetItem* page, const QString& iconName ) const
-    {
-        #if OXYGEN_USE_KDE4
-        page->setIcon( KIcon( iconName ) );
-        #else
-        page->setIcon( QIcon::fromTheme( iconName ) );
-        #endif
+        KPageDialog::hideEvent( event );
     }
 
 }
